@@ -1,13 +1,11 @@
 ################################################################################
-### Part of the surveillance package, http://surveillance.r-forge.r-project.org
-### Free software under the terms of the GNU General Public License, version 2,
-### a copy of which is available at http://www.r-project.org/Licenses/.
-###
 ### Helper functions for neighbourhood weight matrices in hhh4()
 ###
-### Copyright (C) 2012-2016 Sebastian Meyer
-### $Revision: 1687 $
-### $Date: 2016-04-01 21:40:25 +0200 (Fri, 01. Apr 2016) $
+### Copyright (C) 2012-2016,2020,2022 Sebastian Meyer
+###
+### This file is part of the R package "surveillance",
+### free software under the terms of the GNU General Public License, version 2,
+### a copy of which is available at https://www.R-project.org/Licenses/.
 ################################################################################
 
 
@@ -15,8 +13,6 @@ checkNeighbourhood <- function (neighbourhood)
 {
     ## setValidity() in sts.R only guarantees correct 'dim' and 'dimnames'
     ## we also assert numeric or logical matrix with non-NA entries
-    ## FIXME: However, we currently don't check for symmetry and for zeros on
-    ## the diagonal...
     stopifnot(is.matrix(neighbourhood),
               nrow(neighbourhood) == ncol(neighbourhood),
               is.numeric(neighbourhood) | is.logical(neighbourhood),
@@ -26,24 +22,28 @@ checkNeighbourhood <- function (neighbourhood)
 
 
 ### calculate the weighted sum of counts of adjacent (or all other) regions
-### i.e. the nTime x nUnit matrix with elements ne_ti = sum_j w_jit * y_jt
+### i.e. the nTime x nUnit matrix with elements (ti): sum_j w_jit * y_j(t-lag)
 ## W is either a nUnits x nUnits matrix of time-constant weights w_ji
-## or a nUnits x nUnits x nTime array of time-varying weights
+## or a nUnits x nUnits x nTime array of time-varying weights w_jit
+## Note that a missing value in any unit at t-lag gives NA at t,
+## even if w_jit = 0 for that unit (e.g., if own past is missing)
 
 weightedSumNE <- function (observed, weights, lag)
 {
   dimY <- dim(observed)
   nTime <- dimY[1L]
   nUnits <- dimY[2L]
-  tY <- t(observed)                     # -> nUnits x nTime
-  
-  res <- apply(weights, 2L, function (wi)
-               ## if dim(weights)==2 (time-constant weights), length(wi)=nUnits,
-               ## if dim(weights)==3, wi is a matrix of size nUnits x nTime
-               .colSums(tY * wi, nUnits, nTime, na.rm=TRUE))
-  
-  rbind(matrix(NA_real_, lag, nUnits),
-        res[seq_len(nTime-lag),,drop=FALSE])
+
+  if (length(dim(weights)) == 2L) { # fast track for time-constant weights
+      rbind(matrix(NA_real_, lag, nUnits),
+            observed[seq_len(nTime-lag),,drop=FALSE] %*% weights)
+  } else {
+      tYlagged <- t(observed[seq_len(nTime-lag),,drop=FALSE])
+      apply(weights[,,(lag+1L):nTime,drop=FALSE], 2L, function (wi)
+          ## wi and tYlagged are matrices of size nUnits x (nTime-lag)
+          c(rep(NA_real_, lag),
+            .colSums(tYlagged * wi, nUnits, nTime-lag)))
+  }
 }
 
 
@@ -78,7 +78,7 @@ scaleNEweights.list <- function (weights, scale = NULL, normalize = FALSE)
 {
     if (is.null(scale) && !normalize)
         return(weights)
-    
+
     if (normalize) {
         dprod <- function (u, v, du, dv) du * v + u * dv
         dfrac <- function (u, v, du, dv) (du * v - u * dv) / v^2
@@ -129,7 +129,7 @@ scaleNEweights.list <- function (weights, scale = NULL, normalize = FALSE)
                     FUN = scaleNEweights.default,
                     scale = scale)
     }
-    
+
     ## return list with updated functions
     list(w = w, dw = dw, d2w = d2w, initial = weights$initial)
 }
@@ -150,7 +150,7 @@ checkWeightsArray <- function (W, nUnits, nTime, name = deparse(substitute(W)),
     if (any(dim(W)[1:2] != nUnits) || isTRUE(dim(W)[3] != nTime))
         stop("'", name, "' must conform to dimensions ",
              nUnits, " x ", nUnits, " (x ", nTime, ")")
-    if (any(is.na(W))) {
+    if (anyNA(W)) {
         if (islands) # normalization of parametric weights yields division by 0
             warning("neighbourhood structure contains islands")
         stop("missing values in '", name, "' are not allowed")
@@ -206,7 +206,7 @@ checkWeights <- function (weights, nUnits, nTime,
             stop("'", name, "' must be a matrix/array or a list of functions")
         }
     }
-    
+
     ## apply matrix/array checks
     if (is.list(weights)) { # parametric weights
         if (length(dim(testweights)) > 2L)
@@ -234,7 +234,7 @@ checkWeights <- function (weights, nUnits, nTime,
         }
     } else checkWeightsArray(testweights, nUnits, nTime, name = name,
                              check0diag = check0diag)
-    
+
     ## Done
     invisible(TRUE)
 }
