@@ -1,16 +1,14 @@
 ################################################################################
-### Part of the surveillance package, http://surveillance.r-forge.r-project.org
-### Free software under the terms of the GNU General Public License, version 2,
-### a copy of which is available at http://www.r-project.org/Licenses/.
-###
 ### Student (t) kernel f(s) = (||s||^2+sigma^2)^-d
 ### This is a reparametrization of the t-kernel; For d=1, this is the kernel of
 ### the Cauchy density with scale sigma; in Geostatistics, a correlation
 ### function of this kind is known as the Cauchy model.
 ###
 ### Copyright (C) 2013-2014,2017 Sebastian Meyer
-### $Revision: 1890 $
-### $Date: 2017-06-19 17:36:54 +0200 (Mon, 19. Jun 2017) $
+###
+### This file is part of the R package "surveillance",
+### free software under the terms of the GNU General Public License, version 2,
+### a copy of which is available at https://www.R-project.org/Licenses/.
 ################################################################################
 
 
@@ -38,6 +36,7 @@ siaf.student <- function (nTypes = 1, validpars = NULL, engine = "C")
         expression(s2 <- .rowSums(s^2, nrow(s), 2L)),
         expression((s2+sigma^2)^-d)
     ))
+    environment(f) <- baseenv()
 
     ## numerically integrate f over a polygonal domain
     F <- siaf_F_polyCub_iso(intrfr_name = "intrfr.student", engine = engine)
@@ -56,6 +55,7 @@ siaf.student <- function (nTypes = 1, validpars = NULL, engine = "C")
         derivlogd <- log(fvals) * fvals,
         cbind(derivlogsigma, derivlogd, deparse.level = 0)
         )))
+    environment(deriv) <- baseenv()
 
     ## Numerical integration of 'deriv' over a polygonal domain
     Deriv <- siaf_Deriv_polyCub_iso(
@@ -64,12 +64,7 @@ siaf.student <- function (nTypes = 1, validpars = NULL, engine = "C")
 
     ## simulation from the kernel (via polar coordinates)
     simulate <- siaf.simulatePC(intrfr.student)
-
-    ## set function environments to the global environment
-    environment(f) <-  environment(deriv) <- .GlobalEnv
-    ## in F, Deriv, and simulate we need access to the intrfr-functions
-    environment(F) <- environment(Deriv) <- environment(simulate) <-
-        getNamespace("surveillance")
+    environment(simulate) <- getNamespace("surveillance")
 
     ## return the kernel specification
     list(f=f, F=F, deriv=deriv, Deriv=Deriv, simulate=simulate,
