@@ -1,15 +1,13 @@
 ################################################################################
-### Part of the surveillance package, http://surveillance.r-forge.r-project.org
-### Free software under the terms of the GNU General Public License, version 2,
-### a copy of which is available at http://www.r-project.org/Licenses/.
-###
 ### Simulate a point pattern according to a spatio-temporal intensity model of
 ### class "twinstim". The function basically uses Ogata's modified thinning
 ### algorithm (cf. Daley & Vere-Jones, 2003, Algorithm 7.5.V.).
 ###
-### Copyright (C) 2010-2018 Sebastian Meyer
-### $Revision: 2116 $
-### $Date: 2018-04-18 17:22:12 +0200 (Wed, 18. Apr 2018) $
+### Copyright (C) 2010-2018,2021 Sebastian Meyer
+###
+### This file is part of the R package "surveillance",
+### free software under the terms of the GNU General Public License, version 2,
+### a copy of which is available at https://www.R-project.org/Licenses/.
 ################################################################################
 
 ### CAVE:
@@ -86,10 +84,9 @@ simEpidataCS <- function (endemic, epidemic, siaf, tiaf, qmatrix, rmarks,
         stgrid <- check_stgrid(stgrid[grep("^BLOCK$", names(stgrid), invert=TRUE)])
     }
 
-    W <- if (is.null(W)) {
-        cat("Building 'W' as the union of 'tiles' ...\n")
-    	unionSpatialPolygons(tiles)
-    } else check_W(W)  # does as(W, "SpatialPolygons")
+    if (!is.null(W)) {
+        W <- check_W(W)  # does as(W, "SpatialPolygons")
+    }
 
     if (!.skipChecks) {
         cat("Checking 'tiles' ...\n")
@@ -100,9 +97,18 @@ simEpidataCS <- function (endemic, epidemic, siaf, tiaf, qmatrix, rmarks,
                          areas.stgrid = stgrid[["area"]][seq_along(tileLevels)],
                          W = W, keep.data = FALSE)
 
+    if (is.null(W)) {
+        cat("Building 'W' as the union of 'tiles' ...\n")
+        W <- unionSpatialPolygons(tiles)
+    }
+
+    ## empty CRS to avoid costly intermediate CRS checks (and rgdal warnings)
+    if (!missing(events) && !is.null(events))
+        stopifnot(identicalCRS(tiles, events))
+    tiles@proj4string <- events@proj4string <- new("CRS")
+
     ## Transform W to class "owin"
-    Wowin <- as(W, "owin")
-    Wedges <- edges(Wowin, check = FALSE)
+    Wowin <- SpP2owin(W)
     maxExtentOfW <- diameter.owin(Wowin)
 
 
@@ -461,7 +467,7 @@ simEpidataCS <- function (endemic, epidemic, siaf, tiaf, qmatrix, rmarks,
         eventTypes <- as.integer(eventData$type)
         eps.s <- eventData$eps.s
         # distance to the border (required for siafInt below, and for epidataCS)
-        bdist <- bdist(eventCoords, Wedges)
+        bdist <- bdist(eventCoords, Wowin)
         # spatial influence regions of the events
         influenceRegion <- if (nrow(eventCoords) > 0L) .influenceRegions(
             events = SpatialPointsDataFrame(
@@ -765,9 +771,7 @@ simEpidataCS <- function (endemic, epidemic, siaf, tiaf, qmatrix, rmarks,
                 .upperRange <- min(sourceEpss, maxExtentOfW)
                 .eventType <- sample(typeNames[qmatrix[sourceType,]], 1L)
                 .eventTypeCode <- match(.eventType, typeNames)
-                eventLocationIR <- if (constantsiaf) {
-                    as.matrix(coords.ppp(runifpoint(1L, win=sourceIR)))
-                } else {
+
                     eventInsideIR <- FALSE
                     ntries <- 0L
                     while(!eventInsideIR) {
@@ -783,24 +787,17 @@ simEpidataCS <- function (endemic, epidemic, siaf, tiaf, qmatrix, rmarks,
                                                      eventLocationIR[,2],
                                                      sourceIR)
                     }
-                    eventLocationIR
-                }
+
                 .eventLocation <- sourceCoords + eventLocationIR
-                whichTile <- over(SpatialPoints(.eventLocation,
-                                                proj4string=tiles@proj4string),
-                                  tiles)
+                whichTile <- over(SpatialPoints(.eventLocation), tiles)
                 if (is.na(whichTile)) {
                     warning("event generated at (",
                             paste(.eventLocation, collapse=","),
                             ") not in 'tiles'")
                     stop("'tiles' must cover all of 'W'")
                 }
-                .eventTile <- row.names(tiles)[whichTile]
-                .eventTile <- factor(.eventTile, levels=tileLevels)
-                if (is.na(.eventTile))
-                    stop("tile \"", row.names(tiles)[whichTile],
-                         "\" of simulated event is no level of stgrid$tile",
-                         "\n-> verify row.names(tiles)")
+                .eventTile <- factor(row.names(tiles)[whichTile],
+                                     levels = tileLevels)
             }
             .eventType <- factor(.eventType, levels=typeNames)
 
@@ -1057,6 +1054,10 @@ simEndemicEvents <- function (object, tiles)
         row.names = NULL, check.rows = FALSE, check.names = FALSE
     )
 
+    ## empty CRS to avoid spending 3/4 of this function's runtime in rebuild_CRS()
+    proj4string <- tiles@proj4string
+    tiles@proj4string <- new("CRS")
+
     ## sample coordinates from tiles
     nByTile <- tapply(X = nGrid, INDEX = lambdaGrid["tile"], FUN = sum)
     xyByTile <- sapply(
@@ -1074,7 +1075,7 @@ simEndemicEvents <- function (object, tiles)
     events <- SpatialPointsDataFrame(
         coords = do.call("rbind", xyByTile),
         data = events[order(events$tile),],
-        proj4string = tiles@proj4string,
+        proj4string = proj4string,
         match.ID = FALSE)
 
     ## order by time
